/************************************************************************/
/*		aPCI-8132 Device Driver for Windows 95/NT						*/
/*																		*/
/*			apci8132.h	-	Win32 interface definition					*/
/*			date		-	1999/05/13									*/
/************************************************************************/

#if !defined( APCI8132_H )
#define	APCI8132_H

#ifdef	__cplusplus
extern	"C" {
#endif

/*==================*/
/*	Error Code		*/
/*==================*/
#define	APCI8132_SUCCESS				0	/* Successfully proccessed */
#define	APCI8132_ERR_SYSTEM				1	/* Call GetLastError() */
#define	APCI8132_ERR_NO_DEVICE			2	/* No card */
#define	APCI8132_ERR_IN_USE				3	/* Device is in use */
#define	APCI8132_ERR_INVALID_SLOT		4	/* Invalid slot number */
#define	APCI8132_ERR_RESOURCE			5	/* Resource exhaustion */
#define	APCI8132_ERR_INVALID_PORT		6	/* Invalid port */
#define	APCI8132_ERR_INVALID_ARGUMENT	7	/* Invalid argument */
#define	APCI8132_ERR_NO_CREATE			8	/* No created device */

/*==========================================*/
/*	aPCI-8132 card's relative port address	*/
/*==========================================*/
#define	APCI8132_PORT_1		0
#define	APCI8132_PORT_2		1
#define	APCI8132_PORT_3		2
#define	APCI8132_PORT_4		3
#define	APCI8132_PORT_5		4
#define	APCI8132_PORT_6		5
#define	APCI8132_PORT_7		6
#define	APCI8132_PORT_8		7

/*==================*/
/*	Miscellaneous	*/
/*==================*/
#define	APCI8132_MAX_SLOTS	16			/* Maximum number of slots */
#define APCI8132_MAX_PORTS	8			/* Maximum number of user ports */

										/* default search */
#define	APCI8132_SLOT_AUTO		( ( WORD ) ~0U )

/*==============*/
/*	Device ID	*/
/*==============*/
#define	APCI8132_BOARD_ID	0x8132		/* pci bus device id */
#define	APCI8132_VENDOR_ID	0x136c		/* pci bus vendor id */
										/* our device id */
#define	APCI8132_DEVICE_ID	( ( DWORD )APCI8132_BOARD_ID\
							| ( ( DWORD )APCI8132_VENDOR_ID << 16 ) )

/*==================================*/
/*	Resource infomation structure	*/
/*==================================*/
#define	APCI8132_MAX_MEM	9			/* number of memory windows */
#define	APCI8132_MAX_IO		20			/* number of i/o windows */
#define	APCI8132_MAX_IRQ	7			/* number of irqs */
#define	APCI8132_MAX_DMA	7			/* number of dmas */

typedef	struct	_APCI8132RESOURCE {
	DWORD	dwNumMemWindows;					/* Not used */
	DWORD	dwMemBase		[APCI8132_MAX_MEM];	/* Not used */
	DWORD	dwMemLength		[APCI8132_MAX_MEM];	/* Not used */
	DWORD	dwMemAttrib		[APCI8132_MAX_MEM];	/* Not used */
	DWORD	dwNumIOPorts;						/* Num IO ports */
	DWORD	dwIOPortBase	[APCI8132_MAX_IO];	/* I/O port base */
	DWORD	dwIOPortLength	[APCI8132_MAX_IO];	/* I/O port length */
	DWORD	dwNumIRQs;							/* Not used */
	DWORD	dwIRQRegisters	[APCI8132_MAX_IRQ];	/* Not used */
	DWORD	dwIRQAttrib		[APCI8132_MAX_IRQ];	/* Not used */
	DWORD	dwNumDMAs;							/* Not used */
	DWORD	dwDMALst		[APCI8132_MAX_DMA];	/* Not used */
	DWORD	dwDMAAttrib		[APCI8132_MAX_DMA];	/* Not used */
	DWORD	dwReserved1		[3];				/* Not used */
} APCI8132RESOURCE, *PAPCI8132R;

#if !defined( APCI8132_DRIVER )
#define	APCI8132_API

#if !defined( APCI8132_DLL )
	#define APCI8132LIB_API	extern __declspec( dllimport )
#else
	#define APCI8132LIB_API	extern __declspec( dllexport )
#endif

#ifdef _BORLANDC_
	#define EXPVAR			__pascal
#else
	#define	EXPVAR
#endif

/*==================*/
/*	API Functions	*/
/*==================*/

APCI8132LIB_API BOOL	WINAPI	Apci8132GetVersion( PDWORD pdwDllVersion, PDWORD pdwDriverVersion );
APCI8132LIB_API BOOL	WINAPI	Apci8132Create( PWORD pwLogSlot );
APCI8132LIB_API BOOL	WINAPI	Apci8132Close( WORD wLogSlot );
APCI8132LIB_API BOOL	WINAPI	Apci8132GetResource( WORD wLogSlot, PAPCI8132R pres );
APCI8132LIB_API BOOL	WINAPI	Apci8132GetSwitchValue( WORD wLogSlot, PDWORD pdwSwitchValue );
APCI8132LIB_API BOOL	WINAPI	Apci8132InPort( WORD wLogSlot, DWORD dwLogPort, PBYTE pbInValue );
APCI8132LIB_API DWORD	WINAPI	Apci8132GetLastError( WORD wLogSlot );

#endif	/* #if !defined( APCI8132_DRIVER ) */

#ifdef	__cplusplus
}
#endif

#endif	/* #if !defined( APCI8132_H ) */

/**/